.. _local_photometry:

Local Photometry
================

Everything related to local photometry is documented bellow:

.. currentmodule:: hostphot.local_photometry
.. autofunction:: calc_aperture_size
.. autofunction:: extract_aperture
.. autofunction:: extract_local_photometry
.. autofunction:: multi_local_photometry

